Anvil.Queue.Policy.Redundancy (Anvil v0.1.1)

Redundancy assignment policy.

Ensures k independent labels per sample for inter-rater reliability. Tracks label counts and prioritizes under-labeled samples.

Summary

Functions

Updates the label count for a sample with a specific labeler.

Functions

record_label(state, sample_id, labeler_id)

Updates the label count for a sample with a specific labeler.