Anvil.Storage.Postgres (Anvil v0.1.1)
View SourcePostgres storage adapter for Anvil.
Implements the Anvil.Storage behaviour using Ecto and Postgres for durable, scalable storage with multi-tenancy support.
Postgres storage adapter for Anvil.
Implements the Anvil.Storage behaviour using Ecto and Postgres for durable, scalable storage with multi-tenancy support.